@@ -1,4 +1,4 @@
-# Copyright (c) 2007 Thomas Lotze
+# Copyright (c) 2011 Thomas Lotze
 # See also LICENSE.txt
 
 """A WSGI application running Ophelia, and an optional wsgiref server running
@@ -6,13 +6,12 @@ this application.
 """
 
 import sys
-import os.path
 
 import zope.exceptions.exceptionformatter
 
 import ophelia.request
 
-
+
 class Application(object):
     """Ophelia's WSGI application.
     """
@@ -46,6 +45,8 @@ class Application(object):
             exc_info = sys.exc_info()
             msg = "".join(zope.exceptions.exceptionformatter.format_exception(
                 with_filenames=True, *exc_info))
+            if isinstance(msg, unicode):
+                msg = msg.encode('utf-8')
             text = "<pre>\n%s\n</pre>" % msg
             self.report_exception(env, msg)
         else:
@@ -77,7 +78,7 @@ class Application(object):
         </html>
         """.replace(" ", "")
 
-
+
 def wsgiref_server(config_file="", section="DEFAULT"):
     import optparse
     import ConfigParser
